Author: ts
Date: Thu Nov 29 17:38:53 2007
New Revision: 6891

Log:
- Documentation updates.

Modified:
    trunk/Webdav/src/backends/memory.php
    trunk/Webdav/src/backends/simple.php
    trunk/Webdav/src/properties/lockdiscovery.php
    trunk/Webdav/src/properties/lockdiscovery_activelock.php
    trunk/Webdav/src/properties/supportedlock.php
    trunk/Webdav/src/properties/supportedlock_lockentry.php
    trunk/Webdav/src/server_configuration_manager.php
    trunk/Webdav/src/structs/collection.php
    trunk/Webdav/src/structs/display_information.php
    trunk/Webdav/src/structs/display_information_empty.php
    trunk/Webdav/src/structs/display_information_string.php
    trunk/Webdav/src/structs/display_information_xml.php
    trunk/Webdav/src/structs/output_result.php
    trunk/Webdav/src/structs/resource.php
    trunk/Webdav/src/tools/date_time.php
    trunk/Webdav/src/tools/xml.php
    trunk/Webdav/src/transports/header_handler.php
    trunk/Webdav/src/transports/microsoft.php
    trunk/Webdav/src/transports/property_handler.php
    trunk/Webdav/src/transports/property_handlers/nautilus.php

Modified: trunk/Webdav/src/backends/memory.php
==============================================================================
--- trunk/Webdav/src/backends/memory.php [iso-8859-1] (original)
+++ trunk/Webdav/src/backends/memory.php [iso-8859-1] Thu Nov 29 17:38:53 2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing a fake memory webdav backend.
+ * File containing the ezcWebdavMemoryBackend class.
  *
  * @package Webdav
  * @version //autogentag//
@@ -9,13 +9,15 @@
  * @access private
  */
 /**
- * Fake backend to serve some virtual content tree, offering options to cause
+ * Backend that only resides in memory.
+ *
+ * Memory backend to serve some virtual content tree, offering options to cause
  * failures in operations, mainly for testing the webdav server.
  *
- * The fake server is constructed from a multidimentional array structure
- * representing the collections and files. The metadata may only be set by
- * appropriate requests to the backend. No information is stored anywhere, so
- * that every reinitialisations gives you a fresh backend.
+ * The content of the backend is constructed from a multidimentional array
+ * structure representing the collections and files. The metadata may only be
+ * set by appropriate requests to the backend. No information is stored
+ * anywhere, so that every reinitialisations gives you a fresh backend.
  *
  * <code>
  *  $backend = new ezcWebdavMemoryBackend();
@@ -31,7 +33,7 @@
  * </code>
  *
  * This backend does not implement any special features to test the servers
- * capabilities to work with thos features.
+ * capabilities to work with those features.
  *
  * @version //autogentag//
  * @package Webdav

Modified: trunk/Webdav/src/backends/simple.php
==============================================================================
--- trunk/Webdav/src/properties/lockdiscovery.php [iso-8859-1] (original)
+++ trunk/Webdav/src/properties/lockdiscovery.php [iso-8859-1] Thu Nov 29 
17:38:53 2007
@@ -6,6 +6,8 @@
  * @version //autogenlastmodified//
  * @copyright Copyright (C) 2005-2007 eZ systems as. All rights reserved.
  * @license http://ez.no/licenses/new_bsd New BSD License
+ *
+ * @access private
  */
 /**
  * An object of this class represents the Webdav property <lockdiscovery>.
@@ -15,6 +17,8 @@
  *
  * @version //autogenlastmodified//
  * @package Webdav
+ *
+ * @access private
  */
 class ezcWebdavLockDiscoveryProperty extends ezcWebdavLiveProperty
 {

Modified: trunk/Webdav/src/properties/lockdiscovery_activelock.php
==============================================================================
--- trunk/Webdav/src/properties/lockdiscovery_activelock.php [iso-8859-1] 
(original)
+++ trunk/Webdav/src/properties/lockdiscovery_activelock.php [iso-8859-1] Thu 
Nov 29 17:38:53 2007
@@ -6,6 +6,8 @@
  * @version //autogenlastmodified//
  * @copyright Copyright (C) 2005-2007 eZ systems as. All rights reserved.
  * @license http://ez.no/licenses/new_bsd New BSD License
+ *
+ * @access private
  */
 /**
  * Objects of this class are used in the ezcWebdavLockDiscoveryProperty class.
@@ -23,6 +25,8 @@
  *
  * @version //autogenlastmodified//
  * @package Webdav
+ *
+ * @access private
  */
 class ezcWebdavLockDiscoveryPropertyActiveLock extends 
ezcWebdavSupportedLockPropertyLockentry
 {

Modified: trunk/Webdav/src/properties/supportedlock.php
==============================================================================
--- trunk/Webdav/src/properties/supportedlock.php [iso-8859-1] (original)
+++ trunk/Webdav/src/properties/supportedlock.php [iso-8859-1] Thu Nov 29 
17:38:53 2007
@@ -6,6 +6,8 @@
  * @version //autogenlastmodified//
  * @copyright Copyright (C) 2005-2007 eZ systems as. All rights reserved.
  * @license http://ez.no/licenses/new_bsd New BSD License
+ *
+ * @access private
  */
 /**
  * An object of this class represents the Webdav property <supportedlock>.
@@ -15,6 +17,8 @@
  *
  * @version //autogenlastmodified//
  * @package Webdav
+ *
+ * @access private
  */
 class ezcWebdavSupportedLockProperty extends ezcWebdavLiveProperty
 {

Modified: trunk/Webdav/src/properties/supportedlock_lockentry.php
==============================================================================
--- trunk/Webdav/src/properties/supportedlock_lockentry.php [iso-8859-1] 
(original)
+++ trunk/Webdav/src/properties/supportedlock_lockentry.php [iso-8859-1] Thu 
Nov 29 17:38:53 2007
@@ -6,6 +6,8 @@
  * @version //autogenlastmodified//
  * @copyright Copyright (C) 2005-2007 eZ systems as. All rights reserved.
  * @license http://ez.no/licenses/new_bsd New BSD License
+ *
+ * @access private
  */
 /**
  * Objects of this class are used in the ezcWebdavSupportedLockProperty class.
@@ -17,6 +19,8 @@
  *
  * @version //autogenlastmodified//
  * @package Webdav
+ *
+ * @access private
  */
 class ezcWebdavSupportedLockPropertyLockentry extends ezcWebdavLiveProperty
 {

Modified: trunk/Webdav/src/server_configuration_manager.php
==============================================================================
--- trunk/Webdav/src/server_configuration_manager.php [iso-8859-1] (original)
+++ trunk/Webdav/src/server_configuration_manager.php [iso-8859-1] Thu Nov 29 
17:38:53 2007
@@ -1,5 +1,36 @@
 <?php
-
+/**
+ * File containing the ezcWebdavServerConfigurationManager class.
+ *
+ * @package Webdav
+ * @version //autogentag//
+ * @copyright Copyright (C) 2005-2007 eZ systems as. All rights reserved.
+ * @license http://ez.no/licenses/new_bsd New BSD License
+ */
+
+/**
+ * Manages and dispatches server configurations.
+ *
+ * An instance of this class is kept in the singleton instance of [EMAIL 
PROTECTED]
+ * ezcWebdavServer} and keeps track of different server configurations to be
+ * used with different clients.
+ *
+ * Several special configurations exist per default:
+ * - MS InternetExplorer compatible
+ * - GNOME Nautilus compatible
+ *
+ * In addtion, a default configuration that behaves RFC compliant is included
+ * as fallback for any other client.
+ *
+ * Configurations can be accessed by the ArrayAccess and Iterator interfaces.
+ * To insert new configurations, the method [EMAIL PROTECTED] insertBefore()} 
should be
+ * used.
+ * 
+ * @package Webdav
+ * @version //autogen//
+ * @copyright Copyright (C) 2005-2007 eZ systems as. All rights reserved.
+ * @license http://ez.no/licenses/new_bsd New BSD License
+ */
 class ezcWebdavServerConfigurationManager implements ArrayAccess, Iterator
 {
     /**
@@ -12,10 +43,12 @@
     /**
      * Creates a new dispatcher.
      *
-     * This creates a new dispatcher object and registers the default [EMAIL 
PROTECTED]
-     * ezcWebdavServerConfiguration} automatically. That means, all
-     * following should be added by [EMAIL PROTECTED] $this->insertBefore()} 
to ensure,
-     * this catchall will not break the transfer layer.
+     * This creates a new manager object and registers the default [EMAIL 
PROTECTED]
+     * ezcWebdavServerConfiguration} instances automatically. The last added
+     * configuration is the RFC compliant one, which matches for every client
+     * if no other configurations matched before. That means, all following
+     * should be added by [EMAIL PROTECTED] insertBefore()} to ensure, this
+     * catchall will not break the transfer layer.
      * 
      * @return void
      */
@@ -45,7 +78,7 @@
      * in [EMAIL PROTECTED] $this->configurations} minus 1.
      *
      * If these preconditions do not match for the given $offset, an
-     * ezcBaseValueException is thrown.
+     * [EMAIL PROTECTED] ezcBaseValueException} is thrown.
      * 
      * @param ezcWebdavServerConfiguration $config 
      * @param int $offset 

Modified: trunk/Webdav/src/structs/collection.php
==============================================================================
--- trunk/Webdav/src/structs/collection.php [iso-8859-1] (original)
+++ trunk/Webdav/src/structs/collection.php [iso-8859-1] Thu Nov 29 17:38:53 
2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing the class representing collection structs
+ * File containing the ezcWebdavCollection struct.
  *
  * @package Webdav
  * @version //autogentag//
@@ -8,7 +8,10 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * Collection struct
+ * Struct representing collection resources.
+ *
+ * This struct is used to represent collection resources, in contrast to 
[EMAIL PROTECTED]
+ * ezcWebdavResource}, which represents non-collection resources.
  *
  * @version //autogentag//
  * @package Webdav
@@ -18,29 +21,32 @@
 class ezcWebdavCollection extends ezcBaseStruct
 {
     /**
-     * Path to ressource
+     * Path to ressource.
      * 
      * @var string
      */
     public $path;
 
     /**
-     * Array with childs of ressource
+     * Array with children of ressource.
      * 
-     * @var array
+     * @var array(int=>ezcWebdavCollection|ezcWebdavResource)
      */
     public $childs;
 
     /**
      * Live properties of ressource.
      * 
-     * @var array
+     * @var ezcWebdavPropertyStorage
      */
     public $liveProperties;
 
     /**
-     * Construct a collection structure from path, properties and contents of a
-     * ressource.
+     * Creates a new collection struct.
+     *
+     * A new collection struct is created, representing the collection
+     * referenced by $path, with the given $liveProperties and $childs
+     * elements.
      * 
      * @param string $path 
      * @param ezcWebdavPropertyStorage $liveProperties 

Modified: trunk/Webdav/src/structs/display_information.php
==============================================================================
--- trunk/Webdav/src/structs/display_information.php [iso-8859-1] (original)
+++ trunk/Webdav/src/structs/display_information.php [iso-8859-1] Thu Nov 29 
17:38:53 2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing the ezcWebdavDisplayInformation struct.
+ * File containing the ezcWebdavDisplayInformation base struct.
  *
  * @package Webdav
  * @version //autogentag//
@@ -8,11 +8,11 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * Display information.
+ * Display information base class.
  *
- * Used by [EMAIL PROTECTED] ezcWebdavTransport} to transport information on 
displaying a
- * response to the browser.
- *
+ * Instances of classes extending this base class are used inside [EMAIL 
PROTECTED]
+ * ezcWebdavTransport} to encapsulate response information to be displayed.
+ * 
  * @version //autogentag//
  * @package Webdav
  * @copyright Copyright (C) 2005-2007 eZ systems as. All rights reserved.
@@ -22,7 +22,12 @@
 {
     
     /**
-     * Creates a new struct.
+     * Creates a new display information.
+     *
+     * By default an instance of this class carries a [EMAIL PROTECTED] 
ezcWebdavResponse}
+     * $repsonse object, which holds header information, and a $body. The
+     * content of $body depends on the type of display information. Extending
+     * classes may possibly not carry a body at all.
      * 
      * @param ezcWebdavResponse $response 
      * @param DOMDocument|string|null $body 
@@ -43,7 +48,9 @@
 
     /**
      * Representation of the response body.
-     * Contents overwritten in extending structs.
+     *
+     * The concrete data type of this property is defined in the extending
+     * classes.
      * 
      * @var DOMDocument|sring|null
      */

Modified: trunk/Webdav/src/structs/display_information_empty.php
==============================================================================
--- trunk/Webdav/src/structs/display_information_empty.php [iso-8859-1] 
(original)
+++ trunk/Webdav/src/structs/display_information_empty.php [iso-8859-1] Thu Nov 
29 17:38:53 2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing the ezcWebdavDisplayInformation struct.
+ * File containing the ezcWebdavEmptyDisplayInformation struct.
  *
  * @package Webdav
  * @version //autogentag//
@@ -8,10 +8,10 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * Display information.
+ * Display information with no body.
  *
  * Used by [EMAIL PROTECTED] ezcWebdavTransport} to transport information on 
displaying a
- * response to the browser.
+ * response to the browser. This display information does not carry a body.
  *
  * @version //autogentag//
  * @package Webdav

Modified: trunk/Webdav/src/structs/display_information_string.php
==============================================================================
--- trunk/Webdav/src/structs/display_information_string.php [iso-8859-1] 
(original)
+++ trunk/Webdav/src/structs/display_information_string.php [iso-8859-1] Thu 
Nov 29 17:38:53 2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing the ezcWebdavDisplayInformation struct.
+ * File containing the ezcWebdavStringDisplayInformation class.
  *
  * @package Webdav
  * @version //autogentag//
@@ -8,10 +8,10 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * Display information.
+ * Display information with string body.
  *
  * Used by [EMAIL PROTECTED] ezcWebdavTransport} to transport information on 
displaying a
- * response to the browser.
+ * response to the browser. This display information carries a string body.
  *
  * @version //autogentag//
  * @package Webdav
@@ -22,8 +22,10 @@
 {
     
     /**
-     * Creates a new struct.
-     * 
+     * Creates a new display information object.
+     *
+     * This display information must be created with a string $body.
+     *
      * @param ezcWebdavResponse $response 
      * @param string $body 
      * @return void

Modified: trunk/Webdav/src/structs/display_information_xml.php
==============================================================================
--- trunk/Webdav/src/structs/display_information_xml.php [iso-8859-1] (original)
+++ trunk/Webdav/src/structs/display_information_xml.php [iso-8859-1] Thu Nov 
29 17:38:53 2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing the ezcWebdavDisplayInformation struct.
+ * File containing the ezcWebdavXmlDisplayInformation struct.
  *
  * @package Webdav
  * @version //autogentag//
@@ -24,6 +24,8 @@
     /**
      * Creates a new struct.
      * 
+     * This display information must be created with DOMDocument $body.
+     *
      * @param ezcWebdavResponse $response 
      * @param DOMDocument $body 
      * @return void

Modified: trunk/Webdav/src/structs/output_result.php
==============================================================================
--- trunk/Webdav/src/structs/output_result.php [iso-8859-1] (original)
+++ trunk/Webdav/src/structs/output_result.php [iso-8859-1] Thu Nov 29 17:38:53 
2007
@@ -8,10 +8,8 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * Display information.
+ * Struct representing a result to display.
  *
- * Used by [EMAIL PROTECTED] ezcWebdavTransport} to transport information on 
displaying a
- * response to the browser.
  *
  * @version //autogentag//
  * @package Webdav

Modified: trunk/Webdav/src/structs/resource.php
==============================================================================
--- trunk/Webdav/src/structs/resource.php [iso-8859-1] (original)
+++ trunk/Webdav/src/structs/resource.php [iso-8859-1] Thu Nov 29 17:38:53 2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing the class representing resource structs
+ * File containing the ezcWebdavResource struct.
  *
  * @package Webdav
  * @version //autogentag//
@@ -8,7 +8,10 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * Resource struct
+ * Struct class representing a non-collection resource.
+ *
+ * This struct is used to represent non-collection resources, in contrast to
+ * [EMAIL PROTECTED] ezcWebdavCollection}, which represents collection 
resources.
  *
  * @version //autogentag//
  * @package Webdav
@@ -34,14 +37,17 @@
     /**
      * Live properties of resource.
      * 
-     * @var array
+     * @var ezcWebdavPropertyStorage
      */
     public $liveProperties;
 
     /**
-     * Construct a resource structure from path, properties and contents of a
-     * resource.
+     * Creates a new non-collection resource struct.
      * 
+     * A new non-collection resource struct is crenated, representing the
+     * resource referenced by $path, with the given $liveProperties and
+     * $content.
+     *
      * @param string $path 
      * @param ezcWebdavPropertyStorage $liveProperties 
      * @param string $content 

Modified: trunk/Webdav/src/tools/date_time.php
==============================================================================
--- trunk/Webdav/src/tools/date_time.php [iso-8859-1] (original)
+++ trunk/Webdav/src/tools/date_time.php [iso-8859-1] Thu Nov 29 17:38:53 2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing the ezcWebdavezcWebdavDateTime class.
+ * File containing the ezcWebdavDateTime class.
  *
  * @package Webdav
  * @version //autogentag//
@@ -9,9 +9,12 @@
  */
 
 /**
- * This class extends the PHP internal ezcWebdavDateTime class to make it 
serializable.
- * This class is only needed for testing purposes and should be dropped ASAP,
- * if its parents issue is fixed.
+ * DateTime class with serialization support.
+ *
+ * The PHP 5.2 [EMAIL PROTECTED] DateTime} class does not support
+ * serialization/deserialization with maintaining the stored time information.
+ * This class extends DateTime to solve the issue, which is needed especially
+ * when working with persistent [EMAIL PROTECTED] ezcWebdavMemoryBackend} 
instances.
  * 
  * @package Webdav
  * @version //autogen//
@@ -29,11 +32,13 @@
 
     /**
      * Backup the currently stored time.
-     * This methods backs up the time currently stored in the object as an RCF
-     * 2822 formatted string and returns the name of the stored property in an
-     * array to indicate that it should be serialized.
+     *
+     * This method is called right before serialization of the object. It backs
+     * up the current time information as an RCF 2822 formatted string and
+     * returns the name of the property this value is stored inside as an array
+     * to indicate that this property should be serialized.
      * 
-     * @return array(string)
+     * @return array(int=>string)
      */
     public function __sleep()
     {
@@ -43,6 +48,9 @@
 
     /**
      * Restores the backeuped time.
+     *
+     * This method is automatically called after deserializing the object and
+     * restores the backed up time information.
      * 
      * @return void
      */

Modified: trunk/Webdav/src/tools/xml.php
==============================================================================
--- trunk/Webdav/src/tools/xml.php [iso-8859-1] (original)
+++ trunk/Webdav/src/tools/xml.php [iso-8859-1] Thu Nov 29 17:38:53 2007
@@ -8,7 +8,21 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * Description missing
+ * Tool class to work with XML.
+ *
+ * An instance of this tool class is used to perform XML operations while
+ * parsing incoming requests and serializing outgoing responses.
+ *
+ * If a client expects different behavior regarding fundamental XML handling,
+ * this class can be extended. To make it being used for a certain client, the
+ * new class name needs to be specified in an instance of [EMAIL PROTECTED]
+ * ezcWebdacServerConfiguration}, which then needs to be registered in the
+ * [EMAIL PROTECTED] ezcWebdacServerConfigurationManager} instance, located in 
the [EMAIL PROTECTED]
+ * ezcWebdacServer} singleton instance.
+ *
+ * @properties ezcWebdavNamespaceRegistry $namespaceRegistry
+ *             Registry class that keeps track of used namespace URIs and their
+ *             abbreviations.
  *
  * @package Webdav
  * @version //autogen//
@@ -39,6 +53,11 @@
 
     /**
      * Creates a new XML tool.
+     *
+     * Creates an new XML tool instance. If not $namespaceRegistry is provided,
+     * the default [EMAIL PROTECTED] ezcWebdavNamespaceRegistry} will be 
instanciated and
+     * used. The registry can be accessed through the $namespaceRegistry
+     * property.
      * 
      * @param ezcWebdavNamespaceRegistry $namespaceRegistry 
      * @return void
@@ -53,6 +72,7 @@
 
     /**
      * Returns a DOMDocument from the given XML.
+     *
      * Creates a new DOMDocument with the options set in the class constants
      * and loads the optionally given $xml string with settings appropriate to
      * work with it. Returns false if the loading fails.

Modified: trunk/Webdav/src/transports/header_handler.php
==============================================================================
--- trunk/Webdav/src/transports/header_handler.php [iso-8859-1] (original)
+++ trunk/Webdav/src/transports/header_handler.php [iso-8859-1] Thu Nov 29 
17:38:53 2007
@@ -10,11 +10,11 @@
 /**
  * An instance of this class manages header parsing and handling.
  *
- * An object of this class takes care about headers in the [EMAIL PROTECTED]
- * ezcWebdavTransport} to parse incoming headers and serialize outgoing
- * headers.  Like for the [EMAIL PROTECTED] ezcWebdavPropertyHandler}, the 
instance of
- * this class that is used in the current transport layer must be accessable
- * for plugins.
+ * An object of this class takes care about headers in [EMAIL PROTECTED]
+ * ezcWebdavTransport}. It is responsible for parsing incoming headers and
+ * serialize outgoing ones. Like for the [EMAIL PROTECTED] 
ezcWebdavPropertyHandler}, the
+ * instance of this class that is used in the current transport layer must be
+ * accessable for plugins.
  *
  * @package Webdav
  * @version //autogen//
@@ -36,13 +36,6 @@
         'Timeout'        => 'HTTP_TIMEOUT',
         'Server'         => 'SERVER_SOFTWARE',
     );
-
-    /**
-     * Pathfactory to process incoming headers.
-     * 
-     * @var ezcWebdavPathFactory
-     */
-    protected $pathFactory;
 
     /**
      * Returns an array with the given headers.

Modified: trunk/Webdav/src/transports/microsoft.php
==============================================================================
--- trunk/Webdav/src/transports/microsoft.php [iso-8859-1] (original)
+++ trunk/Webdav/src/transports/microsoft.php [iso-8859-1] Thu Nov 29 17:38:53 
2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing the microsoft compliant transport mecanism.
+ * File containing the ezcWebdavMicrosoftCompatibleTransport class.
  *
  * @package Webdav
  * @version //autogentag//
@@ -8,7 +8,7 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * Transport layer for Microsoft clients with RFC incompatible handling.
+ * Transport layer for Microsoft clients with RFC incompatiblities.
  *
  * Clients seen, which need this:
  *  - Microsoft Data Access Internet Publishing Provider Cache Manager

Modified: trunk/Webdav/src/transports/property_handler.php
==============================================================================
--- trunk/Webdav/src/transports/property_handler.php [iso-8859-1] (original)
+++ trunk/Webdav/src/transports/property_handler.php [iso-8859-1] Thu Nov 29 
17:38:53 2007
@@ -8,7 +8,16 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * Description missing
+ * Handles the parsing and serailization of live and dead properties.
+ *
+ * An instance of this class is used by [EMAIL PROTECTED] ezcWebdavTransport} 
and [EMAIL PROTECTED]
+ * ezcWebdavFileBackend} to parse [EMAIL PROTECTED] ezcWebdavLiveProperty} and 
[EMAIL PROTECTED]
+ * ezcWebdavDeadProperty} instances from XML content and to re-serialized
+ * instances of these classes back to XML.
+ *
+ * [EMAIL PROTECTED] ezcWebdavTransport} might be configured to use a 
different property
+ * handler, to adjust the behavior of property handling to specific client
+ * needs. [EMAIL PROTECTED] ezcWebdavFileBackend} always uses this default 
implementation.
  *
  * @package Webdav
  * @version //autogen//
@@ -34,7 +43,15 @@
      *
      * An instance of this class is capable of handling live and dead WebDAV
      * properties. It can extract properties from requests and generate
-     * response information for properties.
+     * response information for properties. If $xml is not specified, the
+     * instance in [EMAIL PROTECTED] ezcWebdavServer} will be used, which 
propably
+     * underlies client specific adjustments.
+     *
+     * The [EMAIL PROTECTED] ezcWebdavXmlTool} instance of [EMAIL PROTECTED] 
ezcWebdavServer} can be
+     * configured using a [EMAIL PROTECTED] ezcWebdavServerConfiguration} in 
the [EMAIL PROTECTED]
+     * ezcWebdavServerConfigurationManager} of the [EMAIL PROTECTED] 
ezcWebdavServer}
+     * singleton instance. The XML instance is created as soon as the server is
+     * configured for a specific client.
      * 
      * @param ezcWebdavXmlTool $xml 
      * @return void
@@ -47,6 +64,17 @@
         }
     }
 
+    /**
+     * Returns the XML tool to work with.
+     *
+     * This method either returns the internally ([EMAIL PROTECTED] $xmlTool}) 
instance of
+     * [EMAIL PROTECTED] ezcWebdavXmlTool} or, if this one is not available, 
the instance
+     * stored in the singleton of [EMAIL PROTECTED] ezcWebdavServer}. The 
latter instance
+     * might be an extended one, which is adjusted to the special needs of a
+     * certain client.
+     * 
+     * @return ezcWebdavXmlTool
+     */
     protected function getXmlTool()
     {
         if ( $this->xmlTool === null )
@@ -64,13 +92,15 @@
      *
      * The list may contain live properties as well as dead ones. Live
      * properties ([EMAIL PROTECTED] ezcWebdavLiveProperty}) as defined in RFC 
2518 are
-     * currently recognized. All other properties in the DAV: namespace are
-     * added as dead properties ([EMAIL PROTECTED] ezcWebdavDeadProperty}). 
Dead
-     * properties are parsed in general in any namespace.
-     *
-     * The properties are stored in the given [EMAIL PROTECTED] 
ezcWebdavPropertyStorage}
-     * $storage. If a $flag value is provided, this one is submitted as the
-     * second parameter to [EMAIL PROTECTED] 
ezcWebdavFlaggedPropertyStorage->attach()}.
+     * currently recognized, except for locking related properties. All other
+     * properties in the DAV: namespace are added as dead properties ([EMAIL 
PROTECTED]
+     * ezcWebdavDeadProperty}). Dead properties are parsed generally in any
+     * namespace.
+     *
+     * The extracted properties are stored in the given [EMAIL PROTECTED]
+     * ezcWebdavPropertyStorage} $storage. If a $flag value is provided, this
+     * one is submitted as the second parameter to [EMAIL PROTECTED]
+     * ezcWebdavFlaggedPropertyStorage->attach()}.
      *  
      * @param DOMNodeList $domNodes 
      * @param ezcWebdavPropertyStorage $storage
@@ -110,7 +140,7 @@
     /**
      * Dispatches the extraction of a live property.
      *
-     * This method takes care that the dispatching to the plugin registry takes
+     * This method takes care for dispatching to the plugin registry takes
      * place before and after the actual live property is extracted.
      * Additionally the extractUnknownLiveProperty is announced, if the
      * property could not be parsed internally. If the property still cannot be
@@ -214,7 +244,7 @@
      * Extract a dead property from a DOMElement.
      *
      * This method is responsible for parsing a [EMAIL PROTECTED] 
ezcWebdavDeadProperty}
-     * (unknown) property from a DOMElement.
+     * (unknown) property from a $domElement.
      * 
      * @param DOMElement $domElement 
      * @return ezcWebdavDeadProperty
@@ -329,8 +359,9 @@
 
     /**
      * Serializes an object of new ezcWebdavBasicPropertyStorage to XML.
+     *
      * Attaches all properties of the $storage to the $parentElement XML
-     * element.
+     * element in their XML representation.
      * 
      * @param new ezcWebdavPropertyStorage $storage 
      * @param DOMElement $parentElement 
@@ -424,9 +455,11 @@
 
     /**
      * Extracts the <link /> XML elements.
+     *
      * This method extracts the <link /> XML elements from the <source />
-     * element and returns the corresponding ezcWebdavSourcePropertyLink object
-     * to be used as the content of ezcWebdavSourceProperty.
+     * element and returns the corresponding [EMAIL PROTECTED]
+     * ezcWebdavSourcePropertyLink} object to be used as the content of [EMAIL 
PROTECTED]
+     * ezcWebdavSourceProperty}.
      * 
      * @param DOMElement $domElement 
      * @return ezcWebdavSourcePropertyLink
@@ -452,7 +485,10 @@
 
     /**
      * Returns the XML representation of a dead property.
-     * Returns a DOMElement, representing the content of the given $property.
+     *
+     * Returns a DOMElement, representing the content of the given $property in
+     * XML. The newly created element is also appended as a child to the given
+     * $parentElement.
      * 
      * @param ezcWebdavDeadProperty $property 
      * @param DOMElement $parentElement 
@@ -474,13 +510,18 @@
 
     /**
      * Returns the XML representation of a live property.
+     *
      * Returns a DOMElement, representing the content of the given $property.
      * The newly created element is also appended as a child to the given
      * $parentElement.
+     *
+     * In case the given property is not recodnized, null is returned to
+     * indicate that a plugin hook must be announced to see if a plugin can
+     * serialize the property.
      * 
      * @param ezcWebdavLiveProperty $property 
      * @param DOMElement $parentElement 
-     * @return DOMElement
+     * @return DOMElement|null
      */
     protected function serializeLiveProperty( ezcWebdavLiveProperty $property, 
DOMElement $parentElement )
     {
@@ -554,6 +595,11 @@
 
     /**
      * Serializes an array of ezcWebdavSourcePropertyLink elements to XML.
+     *
+     * This method takes an array of [EMAIL PROTECTED] 
ezcWebdavSourcePropertyLink}
+     * instances, which are serialized to DOMElement objects (using the given
+     * $dom) to be added to a [EMAIL PROTECTED] ezcWebdavSourceProperty} XML
+     * representation. The DOMElement instances are returned in an array.
      * 
      * @param array(ezcWebdavSourcePropertyLink) $links 
      * @param DOMDocument $dom To create the returned DOMElements.

Modified: trunk/Webdav/src/transports/property_handlers/nautilus.php
==============================================================================
--- trunk/Webdav/src/transports/property_handlers/nautilus.php [iso-8859-1] 
(original)
+++ trunk/Webdav/src/transports/property_handlers/nautilus.php [iso-8859-1] Thu 
Nov 29 17:38:53 2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing the ezcWebdavPropertyHandler class.
+ * File containing the ezcWebdavNautilusPropertyHandler class.
  *
  * @package Webdav
  * @version //autogen//
@@ -8,7 +8,10 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * Description missing
+ * Property handler adjusted for the GNOME Nautilus client.
+ *
+ * This property handler removes the "charset=..." part form getcontentype
+ * properties, since Nautilus displays them not nicely.
  *
  * @package Webdav
  * @version //autogen//
@@ -17,9 +20,15 @@
 {
     /**
      * Returns the XML representation of a live property.
+     *
      * Returns a DOMElement, representing the content of the given $property.
      * The newly created element is also appended as a child to the given
      * $parentElement.
+     *
+     * This method only takes care for [EMAIL PROTECTED] 
ezcWebdavGetContentTypeProperty}
+     * and does not add the "charset=..." part to the generated XML output,
+     * since Nautilus does not display this nicely. All other properties are
+     * dispatched to the default [EMAIL PROTECTED] ezcWebdavPropertyHandler}.
      * 
      * @param ezcWebdavLiveProperty $property 
      * @param DOMElement $parentElement 


--- trunk/Webdav/src/backends/simple.php [iso-8859-1] (original)
+++ trunk/Webdav/src/backends/simple.php [iso-8859-1] Thu Nov 29 17:38:53 2007
@@ -1,6 +1,6 @@
 <?php
 /**
- * File containing a abstract simple webdav backend.
+ * File containing the abstract ezcWebdavSimpleBackend class.
  *
  * @package Webdav
  * @version //autogentag//
@@ -8,12 +8,14 @@
  * @license http://ez.no/licenses/new_bsd New BSD License
  */
 /**
- * This backend provides the generic handling of requests and dispatches the
+ * Abstract base class for common backend operations.
+ *
+ * This base backend provides the generic handling of requests and dispatches 
the
  * requuired actions to some basic manipulation methods, which you are required
- * to implement.
+ * to be implemented.
  *
  * This backend does not provide support for extended Webdav features, like
- * compression, or locking handled by the backend, therefore the getFeatures()
+ * compression, or lock handling by the backend, therefore the getFeatures()
  * method is final. If you want to develop a backend which is capable of manual
  * handling those features directly extend from [EMAIL PROTECTED] 
ezcWebdavBackend}.
  *
@@ -31,7 +33,7 @@
     /**
      * Create a new collection.
      *
-     * Creates a new collection at the given path.
+     * Creates a new collection at the given $path.
      * 
      * @param string $path 
      * @return void
@@ -41,8 +43,8 @@
     /**
      * Create a new resource.
      *
-     * Creates a new resource at the given path, optionally with the given
-     * content.
+     * Creates a new resource at the given $path, optionally with the given
+     * $content.
      * 
      * @param string $path 
      * @param string $content 
@@ -51,9 +53,10 @@
     abstract protected function createResource( $path, $content = null );
 
     /**
      * Set contents of a resource.
      *
      * Change the contents of the given resource to the given content.
      * 
      * @param string $path 
      * @param string $content 
@@ -62,7 +65,9 @@
     abstract protected function setResourceContents( $path, $content );
 
     /**
-     * Get contents of a resource.
+     * Returns the content of a resource.
+     *
+     * Returns the content of the resource identified by $path.
      * 
      * @param string $path 
      * @return string
@@ -70,50 +75,58 @@
     abstract protected function getResourceContents( $path );
 
     /**
-     * Manually set a property on a resource to request it later.
-     * 
-     * @param string $resource 
+     * Manually sets a property on a resource.
+     *
+     * Sets the given $propertyBackup for the resource identified by $path.
+     * 
+     * @param string $path 
      * @param ezcWebdavProperty $property
      * @return bool
      */
-    abstract public function setProperty( $resource, ezcWebdavProperty 
$property );
-
-    /**
-     * Manually remove a property from a resource.
-     * 
-     * @param string $resource 
+    abstract public function setProperty( $path, ezcWebdavProperty $property );
+
+    /**
+     * Manually removes a property from a resource.
+     *
+     * Removes the given $property form the resource identified by $path.
+     * 
+     * @param string $path 
      * @param ezcWebdavProperty $property
      * @return bool
      */
-    abstract public function removeProperty( $resource, ezcWebdavProperty 
$property );
-
-    /**
-     * Reset property storage for a resource.
-     * 
-     * @param string $resource 
+    abstract public function removeProperty( $path, ezcWebdavProperty 
$property );
+
+    /**
+     * Resets the property storage for a resource.
+     *
+     * Discardes the current [EMAIL PROTECTED] ezcWebdavPropertyStorage} of 
the resource
+     * identified by $path and replaces it with the given $properties.
+     * 
+     * @param string $path 
      * @param ezcWebdavPropertyStorage $properties
      * @return bool
      */
-    abstract public function resetProperties( $resource, 
ezcWebdavPropertyStorage $properties );
-
-    /**
-     * Manually get a property on a resource.
-     * 
-     * Get the property with the given name from the given resource. You may
-     * optionally define a namespace to receive the property from.
-     *
-     * @param string $resource 
+    abstract public function resetProperties( $path, ezcWebdavPropertyStorage 
$properties );
+
+    /**
+     * Returns a property of a resource.
+     * 
+     * Returns the property with the given $propertyName, from the resource
+     * identified by $path. You may optionally define a $namespace to receive
+     * the property from.
+     *
+     * @param string $path 
      * @param string $propertyName 
      * @param string $namespace 
      * @return ezcWebdavProperty
      */
-    abstract public function getProperty( $resource, $propertyName, $namespace 
= 'DAV:' );
-
-    /**
-     * Manually get a property on a resource.
-     * 
-     * Get all properties for the given resource as a [EMAIL PROTECTED]
-     * ezcWebdavBasicPropertyStorage}
+    abstract public function getProperty( $path, $propertyName, $namespace = 
'DAV:' );
+
+    /**
+     * Returns all properties for a resource.
+     * 
+     * Returns all properties for the resource identified by $path as a [EMAIL 
PROTECTED]
+     * ezcWebdavBasicPropertyStorage}.
      *
      * @param string $resource 
      * @return ezcWebdavPropertyStorage
@@ -51,9 +53,10 @@
 
     /**
-     * Set contents of a resource.
-     *
-     * Change the contents of the given resource to the given content.
+     * Changes contents of a resource.
+     *
+     * This method is used to change the contents of the resource identified by
+     * $path to the given $content.
      * 
      * @param string $path 

Modified: trunk/Webdav/src/properties/lockdiscovery.php
==============================================================================
-- 
svn-components mailing list
svn-components@lists.ez.no
http://lists.ez.no/mailman/listinfo/svn-components

Reply via email to